@@ -27,6 +27,7 @@ use CSS::Sass;
 
 ################################################################################
 package CSS::Sass::Type;
+our $VERSION = "v3.0.1";
 ################################################################################
 use CSS::Sass qw(import_sv);
 ################################################################################
@@ -168,7 +169,7 @@ sub value {
 	if (scalar(@_) > 1) {
 		${$_[0]}->[0] = defined $_[1] ? $_[1] : 0;
 	}
-	${$_[0]}->[0];
+	sprintf "%g", ${$_[0]}->[0];
 }
 
 sub unit {
@@ -179,7 +180,7 @@ sub unit {
 }
 
 sub stringify {
-	join '', @{${$_[0]}}
+	sprintf "%g%s", @{${$_[0]}};
 }
 
 sub equals {
@@ -306,8 +307,8 @@ sub new { shift->SUPER::new(@_) }
 sub separator { return SASS_SPACE }
 sub stringify { join ' ', @{$_[0]} }
 
-
 ################################################################################
+package CSS::Sass::Type;
 ################################################################################
 1;
 
@@ -315,7 +316,7 @@ __END__
 
 =head1 NAME
 
-CSS::Sass::Types - Data Types for custom Sass Functions
+CSS::Sass::Type - Data Types for custom Sass Functions
 
 =head1 Mapping C<Sass_Values> to perl data structures
 
@@ -337,38 +338,38 @@ You can also return these native perl types from custom functions. They will
 automatically be upgraded to real C<CSS::Sass::Type> objects. All types
 overload the C<stringify> and C<eq> operators (so far).
 
-=head2 C<CSS::Sass::Type>
+=head2 CSS::Sass::Type
 
 Acts as a base class for all other types and is mainly an abstract class.
 It only implements a generic constructor, which accepts native perl data types
 (undef, numbers, strings, array-refs and hash-refs) and C<CSS::Sass::Type> objects.
 
-=head2 C<CSS::Sass::Type::Null>
+=head2 CSS::Sass::Type::Null
 
     my $null = CSS::Sass::Type::Null->new;
     my $string = "$null"; # eq 'null'
     my $value = $null->value; # == undef
 
-=head2 C<CSS::Sass::Type::Boolean>
+=head2 CSS::Sass::Type::Boolean
 
     my $bool = CSS::Sass::Type::Boolean->new(42);
     my $string = "$bool"; # eq 'true'
     my $value = $bool->value; # == 1
 
-=head2 C<CSS::Sass::Type::Number>
+=head2 CSS::Sass::Type::Number
 
     my $number = CSS::Sass::Type::Boolean->new(42, 'px');
     my $string = "$number"; # eq '42px'
     my $value = $number->value; # == 42
     my $unit = $number->unit; # eq 'px'
 
-=head2 C<CSS::Sass::Type::String>
+=head2 CSS::Sass::Type::String
 
     my $string = CSS::Sass::Type->new("foo bar"); # => "foo bar"
     my $quoted = "$string"; # eq '"foo bar"'
     my $unquoted = $string->value; # eq 'foo bar'
 
-=head2 C<CSS::Sass::Type::Color>
+=head2 CSS::Sass::Type::Color
 
     my $color = CSS::Sass::Type::Color->new(64, 128, 32, 0.25);
     my $string = "$color"; # eq 'rgba(64, 128, 32, 0.25)'
@@ -377,19 +378,19 @@ It only implements a generic constructor, which accepts native perl data types
     my $b = $color->b; # == 32
     my $a = $color->a; # == 0.25
 
-=head2 C<CSS::Sass::Type::Map>
+=head2 CSS::Sass::Type::Map
 
     my $map = CSS::Sass::Type::Map->new(key => 'value');
     my $string = "$map"; # eq 'key: value'
     my $value = $map->{'key'}; # eq 'value'
 
-=head2 C<CSS::Sass::Type::List::Comma>
+=head2 CSS::Sass::Type::List::Comma
 
     my $list = CSS::Sass::Type::List::Comma->new('foo', 'bar');
     my $string = "$list"; # eq 'foo, bar'
     my $value = $list->[0]; # eq 'foo'
 
-=head2 C<CSS::Sass::Type::List::Space>
+=head2 CSS::Sass::Type::List::Space
 
     my $list = CSS::Sass::Type::List::Space->new('foo', 'bar');
     my $string = "$list"; # eq 'foo bar'
@@ -404,13 +405,26 @@ L<CSS::Sass>
 David Caldwell E<lt>david@porkrind.orgE<gt>  
 Marcel Greter E<lt>perl-libsass@ocbnet.chE<gt>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 LICENSE
 
-Copyright (C) 2013 by David Caldwell  
-Copyright (C) 2014 by Marcel Greter
+The MIT License (MIT)
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.12.4 or,
-at your option, any later version of Perl 5 you may have available.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+THE SOFTWARE.
 
 =cut
